% Wrapper for using the network to classify waveforms with sample data.
filename = 'sampleData.mat'; %filename that contains the variable "waveforms", 
%                             waveforms is an Nxn array, where N is the number
%                             of waveforms, and n is the number of samples in
%                             each waveform.
gamma = 0.2; %minimum P(spike) value for a waveform to be considered a spike
netName = 'Issar_et_al_2020'; %name of network
                              %the 4 outputs of the trained NASNet must
                              %exist. For this example they would be
                              %Issar_et_al_2020_w_hidden
                              %Issar_et_al_2020_b_hidden
                              %Issar_et_al_2020_w_output
                              %Issar_et_al_2020_b_output
sort_labels = [1 0]; %2x1 array of the desired spike and noise label values.
                     %Must be an integer between 0 and 255.
                     %ex.[1,0], then runNASNet will label spikes 1 and noise 0).
slabel = runNASNet(filename,gamma,netName,sort_labels); %classify waveforms

%plot a selection of the labeled waveforms
load(filename);
spikes = waveforms((slabel==sort_labels(1)),:);
noise = waveforms((slabel==sort_labels(2)),:);

figure;
h1=plot(noise(randi(size(noise,1),50),:)','k'); hold on;
h2=plot(spikes(randi(size(spikes,1),50),:)','g');
ylim([-500,500]); xlim([1,52]); 
ylabel('uV'); legend([h1(1),h2(1)],'noise','spike');